@@ -15,16 +15,16 @@ shiny::tagList(
         names = TRUE,
         extend = TRUE,
         editableNames = TRUE,
-        delta = 1
+        delta = 2,
+        delete = TRUE
       ),
       rows = list(
         names = TRUE,
         extend = TRUE,
         editableNames = TRUE,
-        delta = 1
-      ),
-      copy = TRUE,
-      paste = TRUE
+        delta = 1,
+        delete = TRUE
+      )
     )
   )
 )
